import $ from 'jquery';

/**
 * Lista svojstava proizvoda.
 */
export default class AttributeList
{
    /**
     * Konstruktor.
     *
     * @param el
     */
    constructor(el)
    {
        this.$el = $(el);
        this.$attributes = this.$el.find('.product-attribute__input');
        this.$reset = this.$el.find('.product-attributes__reset');

        $.each(this.$attributes, function(i, select) {
            $(select).on('change', this.onChange.bind(this));
        }.bind(this));

        this.$reset.on('click', this.onReset.bind(this));
    }

    /**
     * Vrijednosti atributa.
     */
    get attributes()
    {
        let attributes = {};

        $.each(this.$attributes, function(i, attribute) {
            let $attribute = $(attribute);

            attributes[$attribute.attr('name')] = $attribute.val();
        });

        return attributes;
    }

    /**
     * Ključ varijacije.
     */
    get variationKey()
    {
        let attributes = this.attributes,
            key = [];

        for (name in attributes) {
            key.push(attributes[name]);
        }

        return key.join('|');
    }

    /**
     * Da li su odabrani svi atributi.
     */
    get valid()
    {
        let valid = true;

        $.each(this.$attributes, function(i, attribute) {
            if ($(attribute).val() === '') {
                valid = false;
                return false;
            }
        });

        return valid;
    }

    /**
     * Kada se vrijednost svojstva promijeni.
     */
    onChange()
    {
        $.each(this.$attributes, function(i, attribute) {
            if ($(attribute).val() !== '') {
                this.$reset.addClass('show');
                return false;
            }
        }.bind(this));

        $(this).trigger('change');
    }

    /**
     * Resetira sve atribute.
     */
    onReset(e)
    {
        e.preventDefault();

        $.each(this.$attributes, function(i, attribute) {
            $(attribute).val('');
        });

        this.$reset.removeClass('show');
    }
}