<?php
namespace Ep\Woo\Product;

/**
 * Class ProductTrait
 *
 * @package Ep\Woo\Entity\Product
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-woocommerce
 */
trait WcProductTrait
{
    /**
     * Get max quantity which can be purchased at once.
     *
     * @since  3.0.0
     * @return int Quantity or -1 if unlimited.
     */
    public function get_max_purchase_quantity()
    {
        if ('0' === $this->get_price()) {
            return 0;
        }

        /** @noinspection PhpUndefinedClassInspection */
        return parent::get_max_purchase_quantity();
    }

    /**
     * Returns the product's active price.
     *
     * @param  string $context What the value is for. Valid values are view and edit.
     * @return string price
     */
    public function get_price($context = 'view')
    {
        $price = $this->get_prop('price', $context);
        return $price === '0' ? '' : $price;
    }

    /**
     * Set gallery attachment ids.
     *
     * @since 3.0.0
     * @param array $image_ids List of image ids.
     */
    public function set_gallery_image_ids($image_ids)
    {
        $this->set_prop('gallery_image_ids', $image_ids);
    }
}